clear;
% This elegant code is primarily divided into three parts.

dirname = 'C:\Documents and Settings\My Documents\ARCADIS Documents\CRDS\tracergas_111210\*.xls'; 
files = dir( 'ST*.xls'); 
countfiles = numel(files); 


    
% This first part performs the steps for the stationary vertical analysis until
% the curve fitting part
% a) Takes account of the 8 second delay
% b) Filters the data that are less than 1.5 m/s



for k1 = 1:countfiles 
    
jadu1 = xlsread(files(k1).name);


n1 = 80; % Taking into account of the 8 second delay

time = double(jadu1(:,1)); 
time = time*24;  
co2 = jadu1((1:end),2); % CO2 concentration
ch4 = jadu1((1:end),3); % Ch4 concentration
lat = jadu1((1:end),4); % GPS Latitude
long = jadu1((1:end),5); % GPS Longitude
ws3 = jadu1((1:end),6); % 3D Speed
wd3 = jadu1((1:end),7); % 3D Wind Direction
ws2 = jadu1((1:end),8); % 2D Speed
wd2 = jadu1((1:end),9); % 2D Wind Direction
temp = jadu1((1:end),10);
pres = jadu1((1:end),12);
ws3w = jadu1((1:end),13); % the w component of the velocity

  co2(1:n1) = []; 
  ch4(1:n1) = [];
  c1 = length(co2); 
  time(c1+1:end) = []; 
   ws3(c1+1:end) = []; 
  wd3(c1+1:end) = []; 
  ws2(c1+1:end) = []; 
  wd2(c1+1:end) = []; 
  temp(c1+1:end) = []; 
  pres(c1+1:end) = []; 
  ws3w(c1+1:end) = []; 
  lat(c1+1:end) = []; 
  long(c1+1:end) = []; 
  
   jadu2 = [time co2 ch4 ws3 wd3 ws2 wd2 temp pres ws3w lat long]; 
   
 
 
   % Removing the rows where the wind speed is less than 1.5 m/s 
   wslimit = 1.5; 
   [r c] = size(jadu2); 
a2 = find(ws3<wslimit); 
jadu2(a2,:) = []; 

xlswrite(['Processed',files(k1).name], jadu2); 

end 

 

% Here, is the beginning of the second part of the code
% This second part of the code performs multiple functions including 
% a) Binning the data in order to perform a Gaussian Curve Fit
% b) Classifies the wind stability class 
% c) Arranges the data in a way such that the maximum is placed at 180
% degree

files2 = dir('Processed*.xls'); 
countfiles2 = numel(files2); 
impnum = [];
disney0 = []; 
coeffi = []; % the coefficients
coeffi1 = []; 


for k2 = 1:countfiles2

a1 = xlsread(files2(k2).name);
% a1 = a1(1:end/2,:); % Reading first half of the data
% a1 = a1(end/2:end,:); % Reading second half of the data
ws = a1(:,4); % 3D Wind Speed
temp = a1(:,8)+273.15; 
pres = a1(:,9); 
a1a = a1(:,5);  % 3D Wind Direction
a1b = a1(:,3); % Methane Concentration
ws3w = a1(:,10); % the w component of the velocity
maxmet = max(a1b) % maximum value of the methane concentration
minmet = min(a1b) % minimum value of the methane concentration
mmet = mean(a1b) 
mws = mean(ws) 
mtemp = mean(temp) 
mpres = mean(pres) 
lat = a1(:,11); 
long = a1(:,12); 
lat1 = lat(1); 
long1 = long(1); 

% For classifying the stability

 swd3 = std(a1a); % standard deviation of the angle
 fprintf('The standard deviation of the wind direction is %.3f degree \n',swd3); 
sws3w = std(ws3w); 
turbuint = sws3w/mws; 
fprintf('The turbulent intensity is %.3f  \n',turbuint); 

disney = files2(k2).name; 
disney1 = isletter(disney); 
disney2 = find(disney1 == 0); 
disney3 = disney(disney2);
disney4 = str2num(disney3(3:end)); 
disney5 = str2num(disney3(1)); 
disney0 = [disney0; disney4 disney5];

% Saving the important values

impnum1= [lat1 long1 maxmet minmet mmet mws mtemp mpres swd3 turbuint]; 
impnum = [impnum; impnum1]; 
xlswrite(['ImpValues_',files2(k2).name], impnum1); 



% Binning

deg = 0:5:360;
i2 = 1:length(deg); 
i1 = 1:length(a1a); 
Mini = min(a1a); 
Maxi = max(a1a);

cut = 0.005* length(a1a); 

lowmet = min(a1b); 
% Subtracting off the background 
for i1 = 1:length(a1b)
   if a1b(i1) ~= 0 
      
a1b(i1) = a1b(i1)-lowmet;
%a1b(i1) = a1b(i1) - min(a1b); 
   else
       a1b(i1) = a1b(i1); 
   end 
end 

% This for loop groups the wind direction in 5 degree increments and adds
% up the corresponding methane concentration values and then takes the avg

res(i2) = 0; 
%count(i2) = 1; % Use this when interested in performing the weighted fit 
count(i2) = 0; 
 for i2 = 1:length(deg)


for i1 = 1:length(a1a) 
    
    if a1a(i1) >= deg(i2) && a1a(i1) < deg(i2+1)
   count(i2)= count(i2) +1 ;
        res(i2)= res(i2)+ a1b(i1) ; 
        
      
 
     %resN = res./count; 
     
        end 
    
    end
 end
 

% This code accounts for the case when the count is equal to zero before
% taking the average

  for i2 = 1:length(deg)
  if count(i2) >= cut
 resN(i2) = res(i2)./count(i2); 
  elseif count(i2) < cut 
      resN(i2) = min(res); 
 end 
  end
 
%   for i2 = 1:length(deg)
%   if count(i2) ~= 0
%  resN(i2) = res(i2)./count(i2); 
%   elseif count(i2) == 0 
%       resN(i2) = min(res); 
%  end 
%  end
%  

% The following piece of code performs the centering such that
 % the maximum is located at 180 degree
 
 degcent = 180; % center of the binning 
 degmax = 360; % maximum of the binning
 degmin = 0; % minimum of the binning
 resNmax = find(resN == max(resN)); 
 resNbtwn = find(resN >= min(resN) & resN <= max(resN)); 
 

 x = (degcent - deg(resNmax)); 
 deg = deg + x; 
 for i1 = 1:length(deg)
     
 if deg(i1) > degmax
     deg(i1) = deg(i1)-degmax; 
  elseif deg(i1) < degmax && deg(i1) >= degmin
     deg(i1) = deg(i1); 
  elseif deg(i1) < degmin
       deg(i1) = deg(i1) + degmax; 

 end 
 end


 
 % The following code will restore the result to the original result
 % We will use this code only when necessary 
 
%  deg1int = find(deg == min(deg)); 
%  deg2 = [deg(1:deg1int - 1)]; 
% %  for i1 = 1:length(deg) 
%  if deg(1) ~=0 
%      deg(1:deg1int-1) = []; 
%      deg = [deg deg2]; 
%  end 
%  end
 
% Here, is the third part of the code where the fitting is performed by
% calling other functions in the given directory 

 resNT = resN';
 degT = deg';

  %This is the plot of the methane with respect to wind direction after
 %applying the bin analysis 
 figure(900)
 plot(deg,res,'k.','linewidth',3)
 title('Methane Concentration while being stationary');
 ylabel('Methane Concentration (AU)'); 
 xlabel ('Wind Direction (Degree)'); 
 grid on 
 box on
 
 
 
 %figure(k2)
 afig = figure('visible','off')
 plot(deg,resN,'b.','linewidth',3)
 set(gca,'fontsize',13);
 title('Normalized Methane Concentration while being stationary');
 ylabel('Norm. Conc. (AU)'); 
 xlabel ('Wind Direction (Degree)'); 
 grid on 
 box on
 
 Maxc = max(count);
 countN = count./Maxc;
 countNI = 1./countN;
 
% figure(933)
% plot(degT,resN,'b.','linewidth',3)
% [sigmaNew,muNew,Anew]=mygaussfit(degT,resN,0.25);
% zz=Anew*exp(-(degT-muNew).^2/(2*sigmaNew^2));
% hold on; plot(degT,zz,'.-r'), grid on; box on; 
% set(gca,'fontsize',13);
% ylabel('Norm. Conc. (PPM)'); 
%  xlabel ('Wind Direction (Degree)'); 
%  legend('Data','Fit')
%  text(250,max(resN),strcat('Sigma Y = ',num2str(sigmaNew), ' Amp =', num2str(Anew)), 'FontSize',10);
% %title(strcat('Gaussain fit:','Sigma =', num2str(sigmaNew), ' Amp =', num2str(Anew)));
% title('Normalized Methane Concentration vs Wind Direction'); 


 
 x = degT;
y = resNT;
dy = countNI;
dyT = dy';

gg = horzcat(resNT,dyT);

f = ezfit(degT,resN,'gauss');
showfit(f,'fitcolor', 'red','maxlengtheq',0);

% fw = ezfit(degT,gg ,'gauss');
% showfit(fw,'fitcolor', 'blue');
grid on
box on
set(gca,'fontsize',13);
ylabel('Norm. Conc. (PPM)'); 
xlabel ('Wind Direction (Degree)'); 
%legend('Data','Unweighted Fit','Weighted Fit'); 
legend('Data','Unweighted Fit'); 
title('Normalized Methane Concentration vs Wind Direction');
text(250,(max(resN)+ min(resN))/2,strcat('Event = ',num2str(disney4),'_',num2str(disney5)), 'FontSize',10);


% Saving Figures

%saveas(figure(k2),'fig'); 
print('-djpeg','-r400',figure(k2)); 



coeffi = [coeffi;f]; 
disp(coeffi(k2).m(1:2))
coeffi1 = [coeffi1; coeffi(k2).m(1:2)]; 
end
close all

% Necessary calculations
sigmadeg = coeffi1(:,2);
sigmar = sigmadeg*(pi/180);
dist = [46.2;33];
sigmadist = 0; 
sigmadist = []; 
for k3 = 1:length(dist) 
    
 sigmadist1 = tan(sigmar(k3)/2)*2*dist(k3); 
sigmadist = [sigmadist;sigmadist1]; 
end





impval = [disney0 impnum coeffi1 dist sigmadist]; 

 xlswrite('Event Date', disney0); 
xlswrite('Summary_Processed', impval); 
xlswrite('Relevant Coefficients', coeffi1); 
