###############################################################################
# Estimate Rate Function
# Halley Brantley
# 10/01/15
library(ggplot2)
library(plyr)
library(pracma)
library(readxl)
###############################################################################
# Folder structure
rm(list=ls())
projfolder <- "E:/PSG_Rcode/Data_Analysis"
datafolder <- file.path(projfolder, "Data")
STRfolder <- file.path(projfolder, "Data", "STR")
funcfolder <- file.path(projfolder, "Functions")
sapply(list.files(funcfolder, full.names=TRUE), source)
###############################################################################
# Define wd bins
binwidth <- 5
# Wind direction filter
wdfilt <- 60

# Concentration time series files
STRfiles <- list.files(STRfolder, full.names=TRUE)
IDs <- substr(STRfiles, nchar(STRfiles)-13, nchar(STRfiles)-4)

# File with ID, lag (between measurement and timestamp), distance, 
# sensor height, source height, and release rate
lagfile <- file.path(datafolder, "CR_lagtimes.csv")

# Create dataframe to store results 
# a_ppm: peak concentration from Gaussian fit
# Ubar: mean 3D wind speed of filtered data (wind direction +/- windfilt)
# PGI: Atmospheric stability class (1-7)
# NonGauss: inidicator of whether concentrations as a function of wd returns 
# to background concentrations on both sides of the peak concentration
# if NonGauss is True, may not want to use estimate
results <- data.frame(ID=IDs, release_rate= NA, PSG=NA, a_ppm=NA, Ubar = NA, PGI = NA, 
                      NonGauss = NA)
# Start progress bar
pb <- txtProgressBar(min = 1, max = length(STRfiles), initial = 0, char = "=",
               width = NA, title, label, style = 1, file = "")
for (i in 1:length(STRfiles)) {
  setTxtProgressBar(pb, i)
  ID <- IDs[i]
  STRfile <- STRfiles[i]
  STR <- importSTR(STRfile, lagfile, ID)
  results[which(results$ID==ID), "release_rate"] <- STR$runinfo[, "release_rate"]
  runEst <- NA
  # Try to calculate PSG, if there is an error, most likely the gaussian fit 
  # did not converge, check that the bin mean concentrations are gaussian and check
  # initial values
  try(runEst <- calcPSG(STR, binwidth, wdfilt, datafolder, plot=TRUE))
  
  if (!is.na(runEst)){
    results[which(results$ID==ID), c("PSG", "a_ppm", "Ubar", "PGI", "NonGauss")] <- 
      c(runEst$PSG, runEst$a_ppm, runEst$Ubar, runEst$PGI, runEst$NonGauss)
  }
}

write.csv(results, file.path(datafolder, "PSG_results.csv"), row.names=FALSE)
